**SES Conda**: A simple concept of SES `Conda` language

*Update log*:
2.0.0`-dev`  **GRAND UPDATE!** We've used `scikit-learn` to advance the accuracy and efficiency of our sentimental prediction function. Well, it's not perfect yet (((  
Please notice that during step-3 of calculation, `numpy.linalg` may fail due to dimensional complexity. Therefore, it is not able to process complex or multi-dimensional data yet. We are trying to fix it soon )   

-------

1.3.1 2025/03/15 The prediction and analysis algorithm are re-designed. 
1.3.0 2025/03/14 Fixed `expo` (stable update) 
1.2.2-dev 2025/03/13 (Experimental) `expo` function included. 
1.1.3 2025/01/16 Fixed syntax errors.
1.1.2 2024/10/2 Fixed some of the `export()` functions. Added a `rels` index in the `database()` function for relationship storage.  
1.1.1 2024/10/2 Added a function(`rels.parse()`) for parsing relationships.  
1.0.3 2024/10/2 Fixed the `database.load`  from  `json()` function. No need to convert anymore.  
